@@ -9,15 +9,15 @@
 #  ifndef QCORODBUS_EXPORT
 #    ifdef QCoro5DBus_EXPORTS
         /* We are building this library */
-#      define QCORODBUS_EXPORT 
+#      define QCORODBUS_EXPORT __attribute__((visibility("default")))
 #    else
         /* We are using this library */
-#      define QCORODBUS_EXPORT 
+#      define QCORODBUS_EXPORT __attribute__((visibility("default")))
 #    endif
 #  endif
 
 #  ifndef QCORODBUS_NO_EXPORT
-#    define QCORODBUS_NO_EXPORT 
+#    define QCORODBUS_NO_EXPORT __attribute__((visibility("hidden")))
 #  endif
 #endif
 
@@ -33,6 +33,7 @@
 #  define QCORODBUS_DEPRECATED_NO_EXPORT QCORODBUS_NO_EXPORT QCORODBUS_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef QCORODBUS_NO_DEPRECATED
 #    define QCORODBUS_NO_DEPRECATED
